@@ -7,9 +7,10 @@ import openvds
 from ovds_utils.exceptions import VDSException
 from ovds_utils.logging import get_logger
 from ovds_utils.metadata import MetadataContainer
-from ovds_utils.ovds import AccessModes, BrickSizes, Components, Dimensions, Formats, create_vds
+from ovds_utils.ovds import LOD, AccessModes, BrickSizes, Components, Dimensions, Formats, Options, create_vds
 from ovds_utils.ovds.utils import get_vds_info
 from ovds_utils.ovds.writing import FORMAT2FLOAT
+from dataclasses import dataclass, field
 
 logger = get_logger(__name__)
 
@@ -84,6 +85,22 @@ class VDSChunksGenerator:
             raise StopIteration
 
 
+class Axis:
+    def __init__(
+        self,
+        samples: int,
+        name: AnyStr,
+        unit: AnyStr,
+        coordinate_min: float,
+        coordinate_max: float
+    ) -> None:
+        self.samples = samples
+        self.name = name
+        self.unit = unit
+        self.coordinate_min = coordinate_min
+        self.coordinate_max = coordinate_max
+
+
 class Channel:
     def __init__(
             self,
@@ -97,8 +114,6 @@ class Channel:
             chunks_count: int = None,
             vds_source=None,
             shape: Sequence[int] = None,
-            begin: Sequence[int] = None,
-            end: Sequence[int] = None
     ) -> None:
         self._vds_source = vds_source
         self.name = name
@@ -106,8 +121,6 @@ class Channel:
         self.unit = unit
         self.accessor = accessor
         self.chunks_count = chunks_count
-        self.begin = begin
-        self.end = end
         self.shape = shape
         self.components = components
         self.value_range_min = value_range_min
@@ -181,6 +194,7 @@ class Channel:
                     end.append(k+1)
         else:
             raise VDSException("Item key is not list of slices or int")
+
         if is_int:
             return self._read_data(self._vds_source, begin, end).__getitem__(
                 tuple(
@@ -190,33 +204,8 @@ class Channel:
         else:
             return self._read_data(self._vds_source, begin, end)
 
-    def _getitem_for_subset_dataset(self, key: Sequence[Union[int, slice]]) -> np.array:
-        # TODO: Add range checks
-        new_key = []
-        if all([isinstance(i, int) for i in key]):
-            new_key = [k+self.begin[i] for i, k in enumerate(key)]
-        elif all([isinstance(i, int) or isinstance(i, slice) for i in key]):
-            for i, k in enumerate(key):
-                if isinstance(k, slice):
-                    new_key.append(
-                        slice(
-                            self.begin[i] + k.start if k.start else self.begin[i],
-                            self.begin[i] + k.stop if k.stop else self.end[i],
-                            None
-                        )
-                    )
-                elif isinstance(k, int):
-                    new_key.append(k+self.begin[i])
-        else:
-            raise VDSException("Item key is not list of slices or int")
-
-        return self._getitem_for_whole_dataset(tuple(new_key))
-
     def __getitem__(self, key: Sequence[Union[int, slice]]) -> np.array:
-        if self.begin and self.end:
-            return self._getitem_for_subset_dataset(key)
-        else:
-            return self._getitem_for_whole_dataset(key)
+        return self._getitem_for_whole_dataset(key)
 
     def commit(self):
         self.accessor.commit()
@@ -224,77 +213,82 @@ class Channel:
 
 class VDS:
     def __init__(
-        self,
-        path: AnyStr,
-        connection_string: AnyStr = "",
-        shape: Sequence[int] = None,
-        databrick_size: BrickSizes = BrickSizes.BrickSize_128,
-        components: Components = Components.Components_1,
-        metadata_dict: MetadataContainer = None,
-        format: Formats = Formats.R32,
-        data: np.array = None,
-        begin: Sequence[int] = None,
-        end: Sequence[int] = None,
-        channels: List[Channel] = None,
+            self,
+            path: AnyStr,
+            connection_string: AnyStr = "",
+            databrick_size: BrickSizes = BrickSizes.BrickSize_128,
+            metadata_dict: MetadataContainer = {},
+            format: Formats = Formats.R32,
+            channels_data: List[np.array] = None,
+            channels: List[Channel] = None,
+            axes: List[Axis] = None,
+            lod=LOD._0,
+            dimensions_nd=Dimensions.Dimensions_012,
+            negative_margin: int = 0,
+            positive_margin: int = 0,
+            options: Options = Options._0,
+            full_resolution_dimension: int = 0,
+            brick_size_2d_multiplier: int = 4,
     ) -> None:
         super().__init__()
         self.path = path
         self.connection_string = connection_string
-        self.begin = begin
-        self.end = end
         self._channels = {}
-        if data is not None and shape is None:
-            shape = data.shape
+        self._axes = {}
+
         try:
             self._vds_source = openvds.open(path, connection_string)
             vds_info = get_vds_info(path, connection_string)
         except RuntimeError as e:
             if str(e) in ("Open error: File::open "):
-                if shape is None:
-                    raise VDSException("Shape was not defined during creating new VDS source.")
                 logger.debug("Creating new VDS source...")
                 self.create(
                     path=path,
                     connection_string=connection_string,
-                    shape=shape,
-                    metadata_dict=metadata_dict,
                     databrick_size=databrick_size,
-                    data=data,
                     channels=channels,
-                    access_mode=AccessModes.Create,
-                    components=components,
+                    axes=axes,
+                    metadata_dict=metadata_dict,
+                    channels_data=channels_data,
                     format=format,
-                    begin=begin,
-                    end=end
+                    access_mode=AccessModes.Create,
+                    dimensions_nd=dimensions_nd,
+                    lod=lod,
+                    positive_margin=positive_margin,
+                    negagitve_margin=negative_margin,
+                    options=options,
+                    full_resolution_dimension=full_resolution_dimension,
+                    brick_size_2d_multiplier=brick_size_2d_multiplier
                 )
                 self = self.__init__(
                     path=path,
                     connection_string=connection_string,
-                    shape=shape,
                     databrick_size=databrick_size,
-                    components=components,
                     metadata_dict=metadata_dict,
                     format=format,
-                    data=data,
-                    begin=begin,
-                    end=end
                 )
                 return
             else:
                 raise VDSException(f"Open VDS resulted with: {str(e)}") from e
+
         self._layout = openvds.getLayout(self._vds_source)
         self._dimensionality = self._layout.getDimensionality()
-        self._axis_descriptors = [
-            self._layout.getAxisDescriptor(dim) for dim in range(self._dimensionality)
-        ]
-        self.chunks_count = self.count_number_of_chunks(self.shape, databrick_size)
+
         vds_info = get_vds_info(path, connection_string)
         _info = vds_info['layoutInfo'] if 'layoutInfo' in vds_info else vds_info
+
+        for i, j in enumerate(_info['axisDescriptors']):
+            self._axes[j['name']] = Axis(
+                samples=j['numSamples'],
+                name=j['name'],
+                unit=j['unit'],
+                coordinate_max=j['coordinateMax'],
+                coordinate_min=j['coordinateMin']
+            )
+        self.chunks_count = self.count_number_of_chunks(self.shape, databrick_size)
         for i, j in enumerate(_info['channelDescriptors']):
             self._channels[j['name']] = Channel(
                 vds_source=self._vds_source,
-                begin=self.begin,
-                end=self.end,
                 shape=self.shape,
                 components=getattr(Components, j['components']),
                 name=j['name'],
@@ -309,7 +303,15 @@ class VDS:
             )
 
     def channel(self, number: int) -> Channel:
-        return list(self._channels.values())[number]
+        return self.channels[number]
+
+    @property
+    def channels(self) -> List[Channel]:
+        return list(self._channels.values())
+
+    @property
+    def axes(self) -> List[Axis]:
+        return list(self._axes.values())
 
     def get_channel(self, name: AnyStr) -> Channel:
         return self._channels[name]
@@ -332,49 +334,53 @@ class VDS:
 
     @property
     def axis_descriptors(self):
-        return tuple(
-            (a.name, a.unit, a.numSamples) for a in self._axis_descriptors[::-1]
-        )
+        return tuple((
+            self._axes[k].name,
+            self._axes[k].unit,
+            self._axes[k].samples
+        ) for k in self._axes)[::-1]
 
     @property
     def shape(self):
-        if self.begin and self.end:
-            return (
-                self.end[2] - self.begin[2],
-                self.end[1] - self.begin[1],
-                self.end[0] - self.begin[0],
-            )
-        return tuple(int(a.numSamples) for a in self._axis_descriptors[::-1])
+        return tuple(self._axes[k].samples for k in self._axes)[::-1]
 
     @staticmethod
     def create(
         path: AnyStr,
         connection_string: AnyStr,
-        shape: Sequence[int],
-        databrick_size=BrickSizes.BrickSize_128,
-        access_mode=AccessModes.Create,
-        components=Components.Components_1,
-        format=Formats.R32,
+        databrick_size: BrickSizes,
+        access_mode: AccessModes,
+        format: Formats,
+        channels: List[Channel],
+        axes: List[Axis],
+        dimensions_nd: Dimensions,
+        positive_margin: int,
+        negagitve_margin: int,
+        full_resolution_dimension: int,
+        brick_size_2d_multiplier: int,
+        lod: LOD,
+        options: Options,
         metadata_dict: MetadataContainer = None,
-        data: np.array = None,
-        begin: Sequence[int] = None,
-        end: Sequence[int] = None,
-        channels: List[Channel] = None,
+        channels_data: List[np.array] = None,
     ):
         return create_vds(
-            path,
-            connection_string,
-            shape,
+            path=path,
+            connection_string=connection_string,
+            metadata_dict=metadata_dict,
+            channels=channels,
+            axes=axes,
             databrick_size=databrick_size.value,
             access_mode=access_mode.value,
-            metadata_dict=metadata_dict if metadata_dict else {},
-            components=components.value,
             format=format.value,
-            channels=channels,
-            data=data,
-            close=True,
-            begin=begin,
-            end=end
+            lod=lod.value,
+            dimensions_nd=dimensions_nd.value,
+            channels_data=channels_data,
+            negative_margin=negagitve_margin,
+            positive_margin=positive_margin,
+            options=options.value,
+            brick_size_2d_multiplier=brick_size_2d_multiplier,
+            full_resolution_dimension=full_resolution_dimension,
+            close=True
         )
 
     @property
